@@ -1,9 +1,12 @@
 package Git::CPAN::Patch;
+BEGIN {
+  $Git::CPAN::Patch::VERSION = '0.4.0';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.3.2';
+'end of module Git::CPAN::Patch';
 
 __END__
 
@@ -13,6 +16,10 @@ __END__
 
 Git::CPAN::Patch - Patch CPAN modules using Git
 
+=head1 VERSION
+
+version 0.4.0
+
 =head1 SYNOPSIS
 
     # import a module:
@@ -97,11 +104,6 @@ Report the managed module
 =back
 
 
-
-=head1 VERSION
-
-This document describes Git::CPAN::Patch version 0.3.2
-
 =head1 BUGS AND LIMITATIONS
 
 Please report any bugs or feature requests to
@@ -179,6 +181,4 @@ to clone:
 =back
 
 
-=cut
-
-
+=cut
\ No newline at end of file
